pub enum ProgressBarTheme {
Red,
Yellow,
Green,
Blue,
Magenta,
Cyan,
}Expand description
Represents different visual themes for the progress bar.
Variants
Implementations
Sourceimpl ProgressBarTheme
impl ProgressBarTheme
Sourcepub fn template(&self) -> &'static str
pub fn template(&self) -> &'static str
Returns the template string for the selected theme, defining the layout and appearance of the progress bar.
Sourcepub fn progress_chars(&self) -> &'static str
pub fn progress_chars(&self) -> &'static str
Returns the characters used to represent the progress of the bar.
Sourcepub fn tick_chars(&self) -> &'static str
pub fn tick_chars(&self) -> &'static str
Returns the characters used to animate the spinner/ticker in the progress bar.