create_progress_bar

Function create_progress_bar 

pub fn create_progress_bar(
    length: usize,
    prefix: &'static str,
    theme: ProgressBarTheme,
) -> ProgressBar
Creates a new progress bar with the specified length and theme.

Arguments

  • length - The total length of the progress bar, representing the total units of work.
  • theme - The theme of the progress bar.

Returns

A ProgressBar that is styled and ready to use.